@@ -1,4 +1,13 @@
 # -*- coding: utf-8 -*-
+#
+# Copyright (c) 2013-2014 Online SAS and Contributors. All Rights Reserved.
+#                         Julien Castets <jcastets@ocs.online.net>
+#                         Romain Gay <rgay@ocs.online.net>
+#                         Kevin Deldycke <kdeldycke@ocs.online.net>
+#
+# Licensed under the BSD 2-Clause License (the "License"); you may not use this
+# file except in compliance with the License. You may obtain a copy of the
+# License at http://opensource.org/licenses/BSD-2-Clause
 
 from itertools import izip_longest
 
@@ -128,12 +137,15 @@ class AccountAPI(API):
     def get_quotas(self, organization):
         """ Gets a list of quotas for the given organization.
         """
-        if not self.auth_token:
-            raise BadToken()
-
         response = self.query().organizations(organization).quotas.get()
         return response['quotas']
 
+    def get_quota(self, organization, resource):
+        """ Gets one quota for the given organization.
+        """
+        quotas = self.get_quotas(organization)
+        return quotas.get(resource)
+
     def has_quota(self, organization, resource, used=None):
         """ Checks quota for a resource
         """
