@@ -1,4 +1,12 @@
 # -*- coding: utf-8 -*-
+#
+# Copyright (c) 2013-2014 Online SAS and Contributors. All Rights Reserved.
+#                         Julien Castets <jcastets@ocs.online.net>
+#                         Kevin Deldycke <kdeldycke@ocs.online.net>
+#
+# Licensed under the BSD 2-Clause License (the "License"); you may not use this
+# file except in compliance with the License. You may obtain a copy of the
+# License at http://opensource.org/licenses/BSD-2-Clause
 
 import unittest
 
@@ -18,10 +26,15 @@ class TestAPI(FakeAPITestCase, unittest.TestCase):
 
     def test_make_requests_session(self):
         # normal use
-        requests_session = API('0xdeadbeef').make_requests_session()
-        self.assertEqual(
-            requests_session.headers.get('X-Auth-Token'), '0xdeadbeef'
-        )
+        requests_session = API(
+            auth_token='0xdeadbeef', user_agent='jamesb0nd'
+        ).make_requests_session()
+
+        self.assertEqual(requests_session.headers.get('X-Auth-Token'),
+                         '0xdeadbeef')
+        self.assertEqual(requests_session.headers.get('User-Agent'),
+                         'jamesb0nd')
+
 
         # no auth provided
         session_of_no_auth_api = API().make_requests_session()
